Module hook
cove_
cli
0.5.3
Module hook
Module Items
Constants
Functions
In cove_
cli::
commands
cove_cli
::
commands
Module
hook
Constants

ASKING_
TOOLS
Tools that represent Claude asking the user a question (not a permission prompt).
Functions

determine_
state
Map a hook event + tool name to the state string that gets written to the event file.
run