Functions
- has_
stale_ hooks - Check if settings.json has cove hooks pointing to a different binary path.
- hooks_
installed - Check if Cove hooks are already installed in settings.json with the correct binary path. Returns false if hooks are missing OR if the binary path is stale.
- install_
hooks - Install Cove hooks into settings.json. Appends to existing hook arrays — does not overwrite.
- run