Module events
cove_
cli
0.5.3
Module events
Module Items
Functions
In crate cove_
cli
cove_cli
Module
events
Functions

events_
dir
Path to the Cove events directory (~/.cove/events/).
find_
session_
id
Find the Claude session_id for a given tmux pane_id by scanning cove event files. Returns the session_id from the file whose last event matches the pane_id with the highest timestamp (handles pane_id recycling).
find_
session_
id_
in
Find the Claude session_id for a given pane_id by scanning event files in the given directory.
write_
event
Append a state event to the session’s event file.
write_
event_
to
Append a state event to a session file in the given directory.