WindowState

Enum WindowState 

pub enum WindowState {
    Fresh,
    Working,
    Asking,
    Waiting,
    Idle,
    Done,
}

Variants



Fresh

New session, no hook events fired yet.



Working

Claude is generating output.



Asking

Claude is waiting for user to answer a question.



Waiting

Claude is waiting for the user to approve a tool use.



Idle

Claude finished answering — waiting for next user message.



Done

Claude process exited — shell prompt visible.