Module hook

Module hook 

Constants

ASKING_TOOLS
Tools that represent Claude asking the user a question (not a permission prompt).

Functions

determine_state
Map a hook event + tool name to the state string that gets written to the event file.
run