Module events

Module events 

Functions

events_dir
Path to the Cove events directory (~/.cove/events/).
find_session_id
Find the Claude session_id for a given tmux pane_id by scanning cove event files. Returns the session_id from the file whose last event matches the pane_id with the highest timestamp (handles pane_id recycling).
find_session_id_in
Find the Claude session_id for a given pane_id by scanning event files in the given directory.
write_event
Append a state event to the session’s event file.
write_event_to
Append a state event to a session file in the given directory.