pub struct ContextManager { /* private fields */ }Implementations
Sourceimpl ContextManager
impl ContextManager
pub fn new() -> Self
pub fn with_generator( generator_fn: impl Fn(&str, &str) -> Result<String, String> + Send + Sync + 'static, ) -> Self
Sourcepub fn get_error(&self, name: &str) -> Option<&str>
pub fn get_error(&self, name: &str) -> Option<&str>
Get the last error for a window, if generation failed.
Sourcepub fn is_loading(&self, name: &str) -> bool
pub fn is_loading(&self, name: &str) -> bool
Whether a context request is currently running for this window.
Sourcepub fn tick(
&mut self,
windows: &[WindowInfo],
states: &HashMap<u32, WindowState>,
selected: usize,
pane_id_for: &impl Fn(u32) -> Option<String>,
cwd_for: &impl Fn(u32) -> Option<String>,
)
pub fn tick( &mut self, windows: &[WindowInfo], states: &HashMap<u32, WindowState>, selected: usize, pane_id_for: &impl Fn(u32) -> Option<String>, cwd_for: &impl Fn(u32) -> Option<String>, )
Run one tick of context orchestration.
- Drains completed results from background threads
- Invalidates cache on state transitions (Working → settled)
- Requests context for the selected window (lazy — only when settled)
- On selection change: refreshes old session (if settled), requests new session